Project
=======

Commercial Support
------------------

.. include:: ../../README.rst
    :start-after: .. begin-support
    :end-before: .. end-support

Funding
-------

Maintaining a project of this nature to align with the latest standards and
expectations demands a significant investment of time and effort. If you are
using this project, especially in a commercial context, then please do consider
`sponsoring <https://github.com/sponsors/pennersr>`_.
